#include QMK_KEYBOARD_H

#define _BASE 0
#define _RAISE 1
#define _LOWER 2

#define SFT_ESC  SFT_T(KC_ESC)
#define CTL_BSPC CTL_T(KC_BSPC)
#define ALT_SPC  ALT_T(KC_SPC)
#define SFT_ENT  SFT_T(KC_ENT)

#define KC_ML KC_MS_LEFT
#define KC_MR KC_MS_RIGHT
#define KC_MU KC_MS_UP
#define KC_MD KC_MS_DOWN
#define KC_MB1 KC_MS_BTN1
#define KC_MB2 KC_MS_BTN1

#define RAISE MO(_RAISE)
#define LOWER MO(_LOWER)

const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
    /* Base (qwerty)
     * +-----------------------------------------+                             +-----------------------------------------+
     * | ESC  |   q  |   w  |   e  |   r  |   t  |                             |   y  |   u  |   i  |   o  |   p  |   \  |
     * |------+------+------+------+------+------|                             |------+------+------+------+------+------|
     * | TAB  |   a  |   s  |   d  |   f  |   g  |                             |   h  |   j  |   k  |   l  |   ;  |   '  |
     * |------+------+------+------+------+------|                             |------+------+------+------+------+------|
     * | SHFT |   z  |   x  |   c  |   v  |   b  |                             |   n  |   m  |   ,  |   .  |   /  |   \  |
     * +------+------+------+------+-------------+                             +-------------+------+------+------+------+
     *               |  LFT |  RGT |                                                         |   [  |   ]  |
     *               +-------------+-------------+                             +-------------+-------------+
     *                             |      |      |                             |      |      |
     *                             |------+------|                             |------+------|
     *                             |      |      |                             |      |      |
     *                             +-------------+                             +-------------+
     *                                           +-------------+ +-------------+
     *                                           |      |      | |      |      |
     *                                           |------+------| |------+------|
     *                                           |      |      | |      |      |
     *                                           +-------------+ +-------------+
     */
    [_BASE] = LAYOUT(
        KC_LOCK,  KC_Q,    KC_W,    KC_E,    KC_R,    KC_T, // 1. vrstica levo
		KC_Y,    KC_U,    KC_I,    KC_O,    KC_P,    KC_BSLS, // 1. vrstica desno

        TG(_RAISE),  LT(_LOWER,KC_A),    LCTL_T(KC_S), LALT_T(KC_D), LSFT_T(KC_F), LT(_RAISE,KC_G), // 2. vrstica levo
		LT(_RAISE,KC_H),    RSFT_T(KC_J),    RALT_T(KC_K),    RCTL_T(KC_L),    LT(_LOWER,KC_SCLN), KC_QUOT, // 2. vrstica desno

		TG(_LOWER), KC_Z,    KC_X,    KC_C,    KC_V,    KC_B, // 3. vrstica levo
		KC_N,    KC_M,    KC_COMM, KC_DOT,  KC_SLSH, KC_BSLS, // 3. vrstica desno
                          KC_LEFT, KC_RIGHT,                                               KC_LBRC, KC_RBRC,
                                            KC_SPC,   KC_BSPC,             KC_TAB,  KC_ENT,
											LALT_T(KC_ESC),   KC_DEL,            KC_END,  KC_RSFT,
                                            KC_END, KC_HOME,             KC_LGUI, KC_LALT
    ),

    /* lower (symbols)
     * +-----------------------------------------+                             +-----------------------------------------+
     * |      |   !  |   @  |   {  |   }  |   |  |                             |   ^  |   7  |   8  |   9  |   *  |  +   |
     * |------+------+------+------+------+------|                             |------+------+------+------+------+------|
     * |      |   #  |   $  |   (  |   )  |   `  |                             |   e  |   4  |   5  |   6  |   -  |  |   |
     * |------+------+------+------+------+------|                             |------+------+------+------+------+------|
     * |      |   %  |   &  |   [  |   ]  |   ~  |                             |   n  |   1  |   2  |   3  |   =  |  _   |
     * +------+------+------+------+-------------+                             +-------------+------+------+------+------+
     *               |  <   |   >  |                                                         |   0  |   .  |
     *               +-------------+-------------+                             +-------------+-------------+
     *                             |      |      |                             |      |      |
     *                             |------+------|                             |------+------|
     *                             |      |      |                             |      |      |
     *                             +-------------+                             +-------------+
     *                                           +-------------+ +-------------+
     *                                           |      |      | |      |      |
     *                                           |------+------| |------+------|
     *                                           |      |      | |      |      |
     *                                           +-------------+ +-------------+
     */
    [_LOWER] = LAYOUT(
        _______, KC_EXLM, KC_AT, KC_LCBR, KC_RCBR, KC_PIPE, // 1. vrstica levo
		KC_CIRC, KC_7,   KC_8,   KC_9,   KC_ASTR,   KC_SLSH,// 1. vrstica desno
		
        _______, KC_HASH, KC_DLR, KC_LPRN, KC_RPRN , KC_GRV,// 2. vrstica levo
		KC_E, KC_4,   KC_5,   KC_6,   KC_MINS, KC_PLUS,// desno

        TG(_LOWER), KC_PERC, KC_AMPR, KC_LBRC, KC_RBRC, KC_TILD,// 3. vrstica levo
		KC_COMM, KC_1,   KC_2,   KC_3,   KC_EQL,  KC_UNDS,// desno
                          KC_LT, KC_GT,                                                 KC_0, KC_DOT,
                                            _______, _______,             _______, _______,
                                            _______, _______,             _______, _______,
                                            _______, _______,             _______, _______
    ),

    /* raise (symbols)
     * +-----------------------------------------+                             +-----------------------------------------+
     * |      |   !  |   @  |   {  |   }  |   |  |                             |  f1  |  f2  |  f3  |  f4  |  f5  | f6   |
     * |------+------+------+------+------+------|                             |------+------+------+------+------+------|
     * |      |  lft |  up  |  dwn |  rgt |   `  |                             |   f7 |   f8 |   f9 | f10  | f11  | f12  |
     * |------+------+------+------+------+------|                             |------+------+------+------+------+------|
     * |      |   %  |   &  |   [  |   ]  |   ~  |                             |   n  |   1  |   2  |   3  |   =  | caps |
     * +------+------+------+------+-------------+                             +-------------+------+------+------+------+
     *               |  <   |   >  |                                                         |   0  |   .  |
     *               +-------------+-------------+                             +-------------+-------------+
     *                             |      |      |                             |      |      |
     *                             |------+------|                             |------+------|
     *                             |      |      |                             |      |      |
     *                             +-------------+                             +-------------+
     *                                           +-------------+ +-------------+
     *                                           |      |      | |      |      |
     *                                           |------+------| |------+------|
     *                                           |      |      | |      |      |
     *                                           +-------------+ +-------------+
     */
    [_RAISE] = LAYOUT(
        _______, KC_ML,   KC_MU, KC_MD, KC_MR, KC_MB1,             KC_F1, KC_F2, KC_F3,  KC_F4,   KC_F5,  KC_F6,
        TG(_RAISE), KC_LEFT, KC_UP  , KC_DOWN, KC_RGHT, KC_MB2,              KC_F7,  KC_F8,  KC_F9,  KC_F10,  KC_F11,  KC_F12,
        _______, _______, KC_PGUP, KC_PGDN, _______, _______,             _______, _______, _______, _______, _______, KC_CAPS,
                          RESET, _______,                                                 KC_EQL,  _______,
											 _______, _______,               _______, _______,             
                                            _______, _______,             _______, _______,
                                            _______, _______,             _______, _______
    )
};

void persistent_default_layer_set(uint16_t default_layer) {
    eeconfig_update_default_layer(default_layer);
    default_layer_set(default_layer);
}
